# SPDX-License-Identifier: MIT
%global forgeurl  https://pagure.io/fonts-rpm-macros
Version: 2.0.5
%forgemeta

#https://src.fedoraproject.org/rpms/redhat-rpm-config/pull-request/51
%global _spectemplatedir %{_datadir}/rpmdevtools/fedora
%global _docdir_fmt     %{name}
%global ftcgtemplatedir %{_datadir}/fontconfig/templates

# Master definition that will be written to macro files
%global _fontbasedir            %{_datadir}/fonts
%global _fontconfig_masterdir   %{_sysconfdir}/fonts
%global _fontconfig_confdir     %{_sysconfdir}/fonts/conf.d
%global _fontconfig_templatedir %{_datadir}/fontconfig/conf.avail

BuildArch: noarch

Name:      fonts-rpm-macros
Release:   %mkrel 6
Summary:   Build-stage rpm automation for fonts packages
Group:     Publishing
License:   GPLv3+
URL:       https://docs.fedoraproject.org/en-US/packaging-guidelines/FontsPolicy/
Source:    %{name}-%{version}.tar.gz
# ovitters: Undo the Requires(meta) change, rpm 4.16 feature that's at least a year away
Patch101:  e433f73ff221fd109b0baaa60dd14c3a0d8528ea-reversed.patch

Requires:  fonts-srpm-macros = %{version}-%{release}
Requires:  fonts-filesystem  = %{version}-%{release}

Provides:  fontpackages-devel = %{version}-%{release}
Obsoletes: fontpackages-devel < %{version}-%{release}
# Tooling dropped for now as no one was willing to maintain it
Obsoletes: fontpackages-tools < %{version}-%{release}

Requires:  fontconfig
Requires:  appstream-util
Requires:  uchardet
# ovitters: required for fontconfig XML validation. Fedora has the xmllint tool
# in the same package as the library
Requires:  libxml2-utils

# For the experimental generator
Requires:  python3dist(ruamel.yaml)
Requires:  python3dist(lxml)

%description
This package provides build-stage rpm automation to simplify the creation of
fonts packages.

It does not need to be included in the default build root: fonts-srpm-macros
will pull it in for fonts packages only.

%package -n fonts-srpm-macros
Summary:   Source-stage rpm automation for fonts packages
Requires:  rpm-mageia-setup-build

%description -n fonts-srpm-macros
This package provides SRPM-stage rpm automation to simplify the creation of
fonts packages.

It limits itself to the automation subset required to create fonts SRPM
packages and needs to be included in the default build root.

The rest of the automation is provided by the fonts-rpm-macros package, that
fonts-srpm-macros will pull in for fonts packages only.

%package -n fonts-filesystem
Summary:   Directories used by font packages
License:   MIT

Provides:  fontpackages-filesystem = %{version}-%{release}
Obsoletes: fontpackages-filesystem < %{version}-%{release}

%description -n fonts-filesystem
This package contains the basic directory layout used by font packages,
including the correct permissions for the directories.

%package -n fonts-rpm-templates
Summary:   Example fonts packages rpm spec templates
License:   MIT

Requires:    fonts-rpm-macros = %{version}-%{release}
Supplements: fonts-rpm-macros = %{version}-%{release}

%description -n fonts-rpm-templates
This package contains documented rpm spec templates showcasing how to use the
macros provided by fonts-rpm-macros to create fonts packages.

%prep
%forgeautosetup -p1
%writevars -f rpm/macros.d/macros.fonts-srpm _fontbasedir _fontconfig_masterdir _fontconfig_confdir _fontconfig_templatedir
for template in templates/rpm/*\.spec ; do
  target=$(echo "${template}" | sed "s|^\(.*\)\.spec$|\1-bare.spec|g")
  grep -v '^#' "${template}" > "${target}"
  touch -r "${template}" "${target}"
done

%install
install -m 0755 -d    %{buildroot}%{_fontbasedir} \
                      %{buildroot}%{_fontconfig_masterdir} \
                      %{buildroot}%{_fontconfig_confdir} \
                      %{buildroot}%{_fontconfig_templatedir}

install -m 0755 -vd   %{buildroot}%{_spectemplatedir}
install -m 0644 -vp   templates/rpm/*spec \
                      %{buildroot}%{_spectemplatedir}
install -m 0755 -vd   %{buildroot}%{ftcgtemplatedir}
install -m 0644 -vp   templates/fontconfig/*{conf,txt} \
                      %{buildroot}%{ftcgtemplatedir}

install -m 0755 -vd   %{buildroot}%{_rpmmacrodir}
install -m 0644 -vp   rpm/macros.d/macros.fonts-* \
                      %{buildroot}%{_rpmmacrodir}
install -m 0755 -vd   %{buildroot}%{_rpmluadir}/fedora/srpm
install -m 0644 -vp   rpm/lua/srpm/*lua \
                      %{buildroot}%{_rpmluadir}/fedora/srpm
install -m 0755 -vd   %{buildroot}%{_rpmluadir}/fedora/rpm
install -m 0644 -vp   rpm/lua/rpm/*lua \
                      %{buildroot}%{_rpmluadir}/fedora/rpm

install -m 0755 -vd   %{buildroot}%{_bindir}
install -m 0755 -vp   bin/* %{buildroot}%{_bindir}

%files
%license LICENSE.txt
%{_bindir}/*
%{_rpmmacrodir}/macros.fonts-rpm*
%{_rpmluadir}/fedora/rpm/*.lua

%files -n fonts-srpm-macros
%license LICENSE.txt
%doc     *.md changelog.txt
%{_rpmmacrodir}/macros.fonts-srpm*
%{_rpmluadir}/fedora/srpm/*.lua

%files -n fonts-filesystem
%dir %{_datadir}/fontconfig
%dir %{_fontbasedir}
%dir %{_fontconfig_masterdir}
%dir %{_fontconfig_confdir}
%dir %{_fontconfig_templatedir}

%files -n fonts-rpm-templates
%license LICENSE-templates.txt
%doc     *.md changelog.txt
%{_spectemplatedir}/*.spec
%dir %{ftcgtemplatedir}
%doc %{ftcgtemplatedir}/*conf
%doc %{ftcgtemplatedir}/*txt


%changelog
* Mon Mar 21 2022 umeabot <umeabot> 2.0.5-6.mga9
+ Revision: 1813134
- Mageia 9 Mass Rebuild

* Tue Aug 25 2020 guillomovitch <guillomovitch> 2.0.5-5.mga8
+ Revision: 1619007
- fix dependencies

* Mon Apr 06 2020 ovitters <ovitters> 2.0.5-4.mga8
+ Revision: 1565207
- add require on libxml2-utils as the generated font subpackages assume it is available

* Mon Apr 06 2020 ovitters <ovitters> 2.0.5-3.mga8
+ Revision: 1565160
- really revert patch

* Mon Apr 06 2020 ovitters <ovitters> 2.0.5-2.mga8
+ Revision: 1565143
- revert usage of Requires(meta); a rpm 4.16 feature Mageia only gets in 1 year

* Sat Apr 04 2020 tv <tv> 2.0.5-1.mga8
+ Revision: 1564336
- 2.0.5

* Thu Apr 02 2020 tv <tv> 2.0.3-2.mga8
+ Revision: 1563994
- fix deps

* Thu Apr 02 2020 tv <tv> 2.0.3-1.mga8
+ Revision: 1563973
- fix missing Group:
- don't use %%{forgesource} as it's not supported on BS yet
+ ovitters <ovitters>
- imported package fonts-rpm-macros

